@@ -52,8 +52,6 @@ mod imp {
 
         #[template_child]
         pub camera_controls: TemplateChild<gtk::Box>,
-        #[template_child]
-        pub countdown_button: TemplateChild<gtk::MenuButton>,
 
         #[template_child]
         pub sidebar_horizontal_start: TemplateChild<gtk::CenterBox>,
@@ -63,6 +61,25 @@ mod imp {
         pub sidebar_vertical_start: TemplateChild<gtk::CenterBox>,
         #[template_child]
         pub sidebar_vertical_end: TemplateChild<gtk::CenterBox>,
+
+        #[template_child]
+        pub horizontal_start_countdown_button: TemplateChild<gtk::Widget>,
+        #[template_child]
+        pub horizontal_start_menu_button: TemplateChild<gtk::Widget>,
+        #[template_child]
+        pub horizontal_end_countdown_button: TemplateChild<gtk::Widget>,
+
+        #[template_child]
+        pub vertical_start_menu_button: TemplateChild<gtk::Widget>,
+        #[template_child]
+        pub vertical_end_menu_button: TemplateChild<gtk::Widget>,
+        #[template_child]
+        pub vertical_end_toggles: TemplateChild<gtk::Widget>,
+        #[template_child]
+        pub vertical_end_countdown_button: TemplateChild<gtk::Widget>,
+
+        #[template_child]
+        pub vertical_end_window_controls: TemplateChild<gtk::WindowControls>,
     }
 
     #[glib::object_subclass]
@@ -91,82 +108,115 @@ mod imp {
         }
 
         fn set_breakpoint(&self, value: crate::Breakpoint) {
-            if value == self.breakpoint.replace(value) {
-                return;
-            }
+            let obj = self.obj();
 
-            self.sidebar_horizontal_start.set_visible(false);
-            self.sidebar_vertical_start.set_visible(false);
+            let is_vertical = matches!(
+                value,
+                crate::Breakpoint::SingleVertical | crate::Breakpoint::DualVertical
+            );
+            let is_mobile = matches!(
+                value,
+                crate::Breakpoint::DualVertical | crate::Breakpoint::DualHorizontal
+            );
+
+            self.sidebar_vertical_start.set_visible(is_vertical);
+            self.sidebar_vertical_end.set_visible(is_vertical);
+
+            self.sidebar_horizontal_start.set_visible(!is_vertical);
+            self.sidebar_horizontal_end.set_visible(!is_vertical);
 
-            self.sidebar_horizontal_end.set_visible(false);
-            self.sidebar_horizontal_end
-                .set_start_widget(gtk::Widget::NONE);
             self.sidebar_horizontal_end
                 .set_center_widget(gtk::Widget::NONE);
 
-            self.sidebar_vertical_end.set_visible(false);
             self.sidebar_vertical_end
                 .set_center_widget(gtk::Widget::NONE);
-            self.sidebar_vertical_end.set_end_widget(gtk::Widget::NONE);
+
+            if is_vertical {
+                self.camera_controls
+                    .set_orientation(gtk::Orientation::Vertical);
+
+                self.camera_controls.set_margin_start(0);
+                self.camera_controls.set_margin_end(0);
+                self.camera_controls.set_margin_top(12);
+                self.camera_controls.set_margin_bottom(12);
+
+                self.sidebar_vertical_end
+                    .set_center_widget(Some(&self.camera_controls.get()));
+            } else {
+                self.camera_controls
+                    .set_orientation(gtk::Orientation::Horizontal);
+
+                self.camera_controls.set_margin_start(12);
+                self.camera_controls.set_margin_end(12);
+                self.camera_controls.set_margin_top(0);
+                self.camera_controls.set_margin_bottom(0);
+
+                self.sidebar_horizontal_end
+                    .set_center_widget(Some(&self.camera_controls.get()));
+            }
+
+            if is_mobile {
+                obj.add_css_class("mobile");
+            } else {
+                obj.remove_css_class("mobile");
+            }
 
             match value {
                 crate::Breakpoint::SingleVertical => {
-                    self.camera_controls
-                        .set_orientation(gtk::Orientation::Vertical);
+                    if let Some(widget) = self.sidebar_vertical_start.center_widget() {
+                        widget.set_visible(false);
+                    }
+                    if let Some(widget) = self.sidebar_vertical_start.end_widget() {
+                        widget.set_visible(false);
+                    }
 
-                    self.sidebar_vertical_end.set_visible(true);
-                    self.sidebar_vertical_end
-                        .start_widget()
-                        .iter()
-                        .for_each(|widget| widget.set_visible(true));
-                    self.sidebar_vertical_end
-                        .set_center_widget(Some(&self.camera_controls.get()));
-                    self.sidebar_vertical_end
-                        .set_end_widget(Some(&self.countdown_button.get()));
+                    self.vertical_start_menu_button.set_visible(false);
+                    self.vertical_end_menu_button.set_visible(true);
+                    self.vertical_end_toggles.set_visible(true);
+                    self.vertical_end_countdown_button.set_visible(true);
                 }
                 crate::Breakpoint::DualVertical => {
-                    self.camera_controls
-                        .set_orientation(gtk::Orientation::Vertical);
+                    if let Some(widget) = self.sidebar_vertical_start.center_widget() {
+                        widget.set_visible(true);
+                    }
+                    if let Some(widget) = self.sidebar_vertical_start.end_widget() {
+                        widget.set_visible(true);
+                    }
 
-                    self.sidebar_vertical_start.set_visible(true);
-                    self.sidebar_vertical_end.set_visible(true);
-                    self.sidebar_vertical_end
-                        .start_widget()
-                        .iter()
-                        .for_each(|widget| widget.set_visible(false));
-                    self.sidebar_vertical_end
-                        .set_center_widget(Some(&self.camera_controls.get()));
+                    self.vertical_start_menu_button.set_visible(true);
+                    self.vertical_end_menu_button.set_visible(false);
+                    self.vertical_end_toggles.set_visible(false);
+                    self.vertical_end_countdown_button.set_visible(false);
                 }
                 crate::Breakpoint::SingleHorizontal => {
-                    self.camera_controls
-                        .set_orientation(gtk::Orientation::Horizontal);
+                    if let Some(widget) = self.sidebar_horizontal_start.center_widget() {
+                        widget.set_visible(false);
+                    }
+                    if let Some(widget) = self.sidebar_horizontal_end.end_widget() {
+                        widget.set_visible(true);
+                    }
 
-                    self.sidebar_horizontal_end.set_visible(true);
-                    self.sidebar_horizontal_end
-                        .set_start_widget(Some(&self.countdown_button.get()));
-                    self.sidebar_horizontal_end
-                        .set_center_widget(Some(&self.camera_controls.get()));
-                    self.sidebar_horizontal_end
-                        .end_widget()
-                        .iter()
-                        .for_each(|widget| widget.set_visible(true));
+                    self.horizontal_start_countdown_button.set_visible(false);
+                    self.horizontal_start_menu_button.set_visible(false);
+                    self.horizontal_end_countdown_button.set_visible(true);
                 }
                 crate::Breakpoint::DualHorizontal => {
-                    self.camera_controls
-                        .set_orientation(gtk::Orientation::Horizontal);
+                    if let Some(widget) = self.sidebar_horizontal_start.center_widget() {
+                        widget.set_visible(true);
+                    }
+                    if let Some(widget) = self.sidebar_horizontal_end.end_widget() {
+                        widget.set_visible(false);
+                    }
 
-                    self.sidebar_horizontal_start.set_visible(true);
-                    self.sidebar_horizontal_end.set_visible(true);
-                    self.sidebar_horizontal_end
-                        .set_center_widget(Some(&self.camera_controls.get()));
-                    self.sidebar_horizontal_end
-                        .end_widget()
-                        .iter()
-                        .for_each(|widget| widget.set_visible(false));
+                    self.horizontal_start_countdown_button.set_visible(true);
+                    self.horizontal_start_menu_button.set_visible(true);
+                    self.horizontal_end_countdown_button.set_visible(false);
                 }
             }
 
-            self.obj().notify_breakpoint();
+            if value != self.breakpoint.replace(value) {
+                obj.notify_breakpoint();
+            }
         }
 
         #[template_callback]
@@ -262,6 +312,19 @@ mod imp {
                     "draw-guidelines",
                 )
                 .build();
+
+            // TODO remove if
+            // https://gitlab.gnome.org/GNOME/gtk/-/merge_requests/5960 ever
+            // lands.
+            obj.update_window_controls();
+            obj.settings().connect_gtk_decoration_layout_notify(
+                glib::clone!(@weak obj => move |_| {
+                    obj.update_window_controls();
+                }),
+            );
+
+            // This makes sure the default state is properly set.
+            obj.set_breakpoint(crate::Breakpoint::default());
         }
 
         fn dispose(&self) {
@@ -473,6 +536,18 @@ impl Camera {
             }
         }
     }
+
+    fn update_window_controls(&self) {
+        let imp = self.imp();
+
+        let decoration_layout = self.settings().gtk_decoration_layout().and_then(|layout| {
+            layout
+                .split_once(':')
+                .map(|(_start, end)| end.split(',').rev().collect::<Vec<_>>().join(","))
+        });
+        imp.vertical_end_window_controls
+            .set_decoration_layout(decoration_layout.as_deref());
+    }
 }
 
 async fn stream() -> ashpd::Result<RawFd> {
