@@ -70,6 +70,7 @@ mod imp {
                         CaptureMode::Video => {
                             log::error!("Could not record video: {err}");
                             window.send_toast(&gettext("Could not record video"));
+                            window.imp().recording_active.set(false);
                         }
                     }
                 };
@@ -246,7 +247,7 @@ impl Window {
             .application_name(gettext("Snapshot"))
             .application_icon(APP_ID)
             .license_type(gtk::License::Gpl30)
-            .issue_url("https://gitlab.gnome.org/Incubator/snapshot/-/issues/new")
+            .issue_url("https://gitlab.gnome.org/GNOME/Incubator/snapshot/-/issues/new")
             .version(VERSION)
             .translator_credits(gettext("translator-credits"))
             .developer_name(gettext("The GNOME Project"))
@@ -297,6 +298,7 @@ impl Window {
                             CaptureMode::Video => {
                                 log::error!("Could not record video: {err}");
                                 window.send_toast(&gettext("Could not record video"));
+                                window.imp().recording_active.set(false);
                             }
                         }
                     };
